==> kadu_0.5.0.orig.tar.gz: kadu/modules/account_management/translations/account_management_pl.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>AccountManagement</name>
    <message>
        <source>Unregister user</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <source>Register &amp;new user</source>
        <translation>Zarejestruj &amp;nowego użytkownika</translation>
    </message>
    <message>
        <source>Remind &amp;password</source>
        <translation>Przypomnij ha&amp;sło</translation>
    </message>
    <message>
        <source>&amp;Change password / email</source>
        <translation>Zmień &amp;hasło / email</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to change your current password or e-mail.</source>
        <translation>To okno dialogowe pozwala zmienić bieżące hasło lub e-mail.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nowy e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nowe hasło:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Powtórz hasło:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Change password</source>
        <translation>Zmień hasło</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Błędne dane w  wymaganych polach.
Hasła  muszą być identyczne w obu polach!</translation>
    </message>
    <message>
        <source>Change password / email</source>
        <translation>Zmień hasło / email</translation>
    </message>
</context>
<context>
    <name>Register</name>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Zarejestruj</translation>
    </message>
    <message>
        <source>Create config file</source>
        <translation>Utwórz plik konfiguracyjny</translation>
    </message>
    <message>
        <source>Write the newly obtained UIN and password into a clean configuration file
This will erase your current config file contents if you have one</source>
        <translation>Nowy numer GG oraz hasło zostaną zapisane do pliku
konfiguracyjnego. Stary plik zostanie nadpisany.</translation>
    </message>
    <message>
        <source>Register user</source>
        <translation>Zarejestruj nowego użytkownika</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Wypełnij wszystkie pola</translation>
    </message>
    <message>
        <source>Registration was successful. Your new number is %1.
Store it in a safe place along with the password.
Now add your friends to the userlist.</source>
        <translation>Rejestracja zakończona. Twój nowy numer to: %1.
Zapisz go wraz z hasłem w bezpiecznym miejscu.
Teraz możesz dodać znajomych do listy kontaktów.</translation>
    </message>
    <message>
        <source>This dialog box allows you to register a new account.</source>
        <translation>To okno dialogowe pozwala zarejestrowac nowe konto.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>New email:</source>
        <translation>Nowy e-mail:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>Nowe hasło:</translation>
    </message>
    <message>
        <source>Retype new password:</source>
        <translation>Powtórz hasło:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Błędne dane w  wymaganych polach.
Hasła  muszą być identyczne w obu polach!</translation>
    </message>
    <message>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Wystąpił błąd podczas rejestracji. Proszę spróbowac później.</translation>
    </message>
</context>
<context>
    <name>RemindPassword</name>
    <message>
        <source>Error during remind password</source>
        <translation>Błąd podczas przypominania hasła</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>This dialog box allows you to ask server to remind your current password.</source>
        <translation>To okno dialogowe pozwala zapytać serwer o przypomnienie bieżacego hasła.</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>Email (as during registration):</source>
        <translation>E-mail (podany przy rejestracji):</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>Your password has been send on your email</source>
        <translation>Twoje hasło zostało wysłane na twój e-mail</translation>
    </message>
    <message>
        <source>Remind password</source>
        <translation>Przypomnij hasło</translation>
    </message>
</context>
<context>
    <name>Unregister</name>
    <message>
        <source>Unregister</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <source>Unregister user</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <source>Please fill out all fields</source>
        <translation>Wypełnij wszystkie pola</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>No user</source>
        <translation>Brak użytkownika</translation>
    </message>
    <message>
        <source>Unregistation was successful. Now you don&apos;t have any GG number :(</source>
        <translation>Wyrejestrowanie przebiegło prawidłowo.
Teraz już nie masz numeru GG :(</translation>
    </message>
    <message>
        <source>UIN and password</source>
        <translation>Numer GG i hasło</translation>
    </message>
    <message>
        <source>UIN:</source>
        <translation>Numer GG: </translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>An error has occured while unregistration. Please try again later.</source>
        <translation>Wystąpił błąd podczas wyrejestrowywania. Proszę spróbowac później.</translation>
    </message>
    <message>
        <source>This dialog box allows you to unregister your account. Be aware of using this option. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;It will permanently delete your UIN and you will not be able to use it later!&lt;/b&gt;&lt;/font&gt;</source>
        <translation>To okno dialogowe pozwala na trwałe wyrejestrowanie użytkownika z serwera Gadu-Gadu. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;Musisz sobie zdawć sprawę że spowoduje to nieodwracalne usunięcie numeru GG z serwera i nigdy już nie będziesz mógł z niego korzystać!&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.orig.tar.gz: kadu/modules/account_management/translations/account_management_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl_PL">
<context>
    <name>AccountManagement</name>
    <message>
        <location filename="../account_management.cpp" line="57"/>
        <source>Unregister user</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <location filename="../account_management.cpp" line="58"/>
        <source>Register &amp;new user</source>
        <translation>Zarejestruj &amp;nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../account_management.cpp" line="60"/>
        <source>Remind &amp;password</source>
        <translation>Przypomnij ha&amp;sło</translation>
    </message>
    <message>
        <location filename="../account_management.cpp" line="59"/>
        <source>&amp;Change password / email</source>
        <translation>Zmień &amp;hasło / email</translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <location filename="../change_password.cpp" line="80"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="50"/>
        <source>This dialog box allows you to change your current password or e-mail.</source>
        <translation>To okno dialogowe pozwala zmienić bieżące hasło lub e-mail.</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="56"/>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="58"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="63"/>
        <source>New email:</source>
        <translation>Nowy e-mail:</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="66"/>
        <source>New password:</source>
        <translation>Nowe hasło:</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="70"/>
        <source>Retype new password:</source>
        <translation>Powtórz hasło:</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="81"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="122"/>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Błędne dane w  wymaganych polach.
Hasła  muszą być identyczne w obu polach!</translation>
    </message>
    <message>
        <location filename="../change_password.cpp" line="32"/>
        <source>Change password / email</source>
        <translation>Zmień hasło / email</translation>
    </message>
</context>
<context>
    <name>Register</name>
    <message>
        <location filename="../register.cpp" line="104"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="131"/>
        <source>Register</source>
        <translation>Zarejestruj</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="123"/>
        <source>Create config file</source>
        <translation>Utwórz plik konfiguracyjny</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="124"/>
        <source>Write the newly obtained UIN and password into a clean configuration file
This will erase your current config file contents if you have one</source>
        <translation>Nowy numer GG oraz hasło zostaną zapisane do pliku
konfiguracyjnego. Stary plik zostanie nadpisany.</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="78"/>
        <source>Register user</source>
        <translation>Zarejestruj nowego użytkownika</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="180"/>
        <source>Please fill out all fields</source>
        <translation>Wypełnij wszystkie pola</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="203"/>
        <source>Registration was successful. Your new number is %1.
Store it in a safe place along with the password.
Now add your friends to the userlist.</source>
        <translation>Rejestracja zakończona. Twój nowy numer to: %1.
Zapisz go wraz z hasłem w bezpiecznym miejscu.
Teraz możesz dodać znajomych do listy kontaktów.</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="96"/>
        <source>This dialog box allows you to register a new account.</source>
        <translation>To okno dialogowe pozwala zarejestrować nowe konto.</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="102"/>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="109"/>
        <source>New email:</source>
        <translation>Nowy e-mail:</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="112"/>
        <source>New password:</source>
        <translation>Nowe hasło:</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="116"/>
        <source>Retype new password:</source>
        <translation>Powtórz hasło:</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="132"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="174"/>
        <source>Error data typed in required fields.

Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
        <translation>Błędne dane w  wymaganych polach.
Hasła  muszą być identyczne w obu polach!</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="209"/>
        <source>An error has occured while registration. Please try again later.</source>
        <translation>Wystąpił błąd podczas rejestracji. Proszę spróbować później.</translation>
    </message>
    <message>
        <location filename="../register.cpp" line="186"/>
        <source>Email address you have entered is not valid</source>
        <translation>Podany adres e-mail jest nieprawidłowy</translation>
    </message>
</context>
<context>
    <name>RemindPassword</name>
    <message>
        <location filename="../remind_password.cpp" line="125"/>
        <source>Error during remind password</source>
        <translation>Błąd podczas przypominania hasła</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="72"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="51"/>
        <source>This dialog box allows you to ask server to remind your current password.</source>
        <translation>To okno dialogowe pozwala zapytać serwer o przypomnienie bieżacego hasła.</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="57"/>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="62"/>
        <source>Email (as during registration):</source>
        <translation>E-mail (podany przy rejestracji):</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="123"/>
        <source>Your password has been send on your email</source>
        <translation>Twoje hasło zostało wysłane na twój e-mail</translation>
    </message>
    <message>
        <location filename="../remind_password.cpp" line="33"/>
        <source>Remind password</source>
        <translation>Przypomnij hasło</translation>
    </message>
</context>
<context>
    <name>Unregister</name>
    <message>
        <location filename="../unregister.cpp" line="78"/>
        <source>Unregister</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="34"/>
        <source>Unregister user</source>
        <translation>Wyrejestruj użytkownika</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="120"/>
        <source>Please fill out all fields</source>
        <translation>Wypełnij wszystkie pola</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="154"/>
        <source>No user</source>
        <translation>Brak użytkownika</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="135"/>
        <source>Unregistation was successful. Now you don&apos;t have any GG number :(</source>
        <translation>Wyrejestrowanie przebiegło prawidłowo.
Teraz już nie masz numeru GG :(</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="60"/>
        <source>UIN and password</source>
        <translation>Numer GG i hasło</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="65"/>
        <source>UIN:</source>
        <translation>Numer GG: </translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="68"/>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="79"/>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="140"/>
        <source>An error has occured while unregistration. Please try again later.</source>
        <translation>Wystąpił błąd podczas wyrejestrowywania. Proszę spróbować później.</translation>
    </message>
    <message>
        <location filename="../unregister.cpp" line="54"/>
        <source>This dialog box allows you to unregister your account. Be aware of using this option. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;It will permanently delete your UIN and you will not be able to use it later!&lt;/b&gt;&lt;/font&gt;</source>
        <translation>To okno dialogowe pozwala na trwałe wyrejestrowanie użytkownika z serwera Gadu-Gadu. &lt;font color=&quot;red&quot;&gt;&lt;b&gt;Musisz sobie zdawać sprawę że spowoduje to nieodwracalne usunięcie numeru GG z serwera i nigdy już nie będziesz mógł z niego korzystać!&lt;/b&gt;&lt;/font&gt;</translation>
    </message>
</context>
</TS>
